@@ -5,6 +5,9 @@ from .utils.load_yaml import YamlConfig
 import os  
 import importlib  
 import logging  
+from fastapi.middleware.cors import CORSMiddleware
+
+
 
 logging.basicConfig(level=logging.INFO)  
 logger = logging.getLogger(__name__)  
@@ -17,7 +20,13 @@ class HTTPServer:
         self.router = APIRouter()  
         self.config_path = config_path 
         self.auth_middleware = auth_middleware
-  
+        self.app.add_middleware(
+            CORSMiddleware,
+            allow_origins=["*"],  # 允许所有来源，您可以指定具体的来源，如 ["http://example.com"]
+            allow_credentials=True,
+            allow_methods=["*"],  # 允许所有方法，您可以指定具体的方法，如 ["GET", "POST"]
+            allow_headers=["*"],  # 允许所有头信息，您可以指定具体的头信息，如 ["Content-Type"]
+        )
     def call_func(self, modle_name: str, func_name: str) -> callable:  
         try:  
             module = importlib.import_module(modle_name)  
